# `wap new-config`

`wap new-config [OPTIONS]`

Create a new configuration file in the current directory by answering some questions.

!!! note

    If you want to create a whole new project, use [`wap new-project`](./new-project.md)

## Options

### `--config-path`

`--config-path FILE`

This path tells wap where to save your new configuration, overriding the default of `wap.json`.

### `--help`

`--help`

Show the built-in help text and exit.
